@@ -50,7 +50,7 @@ def run_demo():
     print "hist -f ./data/exp.txt -s 35.0 -b 40"
     plot_hist('./data/exp.txt', height=35.0, bincount=40)
 
-def plot_hist(f, height=20.0, bincount=None, pch="o", colour="white", title="", xlab=None):
+def plot_hist(f, height=20.0, bincount=None, pch="o", colour="white", title="", xlab=None, nosummary=True):
     "plot a histogram given a file of numbers"
     if pch is None:
         pch = "o"
@@ -121,16 +121,18 @@ def plot_hist(f, height=20.0, bincount=None, pch="o", colour="white", title="",
             print
     center = max(map(len, map(str, [n, min_val, mean, max_val])))
     center += 15
-    print
-    print "-"*(2 + center)
-    print "|" + "Summary".center(center) + "|"
-    print "-"*(2 + center)
-    summary = "|" + ("observations: %d" % n).center(center) + "|\n"
-    summary += "|" + ("min value: %f" % min_val).center(center) + "|\n"
-    summary += "|" + ("mean : %f" % mean).center(center) + "|\n"
-    summary += "|" + ("max value: %f" % max_val).center(center) + "|\n"
-    summary += "-"*(2 + center)
-    print summary
+    
+    if nosummary is not True:
+        print
+        print "-"*(2 + center)
+        print "|" + "Summary".center(center) + "|"
+        print "-"*(2 + center)
+        summary = "|" + ("observations: %d" % n).center(center) + "|\n"
+        summary += "|" + ("min value: %f" % min_val).center(center) + "|\n"
+        summary += "|" + ("mean : %f" % mean).center(center) + "|\n"
+        summary += "|" + ("max value: %f" % max_val).center(center) + "|\n"
+        summary += "-"*(2 + center)
+        print summary
 
 
 if __name__=="__main__":
@@ -150,9 +152,10 @@ if __name__=="__main__":
     parser.add_option('-c', '--colour', help='colour of the plot (%s)' % ", ".join([c for c in bcolours.keys() if c != 'ENDC']),
                       default='white', dest='colour')
     parser.add_option('-d', '--demo', help='run demos', action='store_true', dest='demo')
+    parser.add_option('-n', '--nosummary', help='run demos', action='store_true', dest='nosummary')
 
     (opts, args) = parser.parse_args()
-   
+
     if opts.f is None:
         if len(args) > 0:
             opts.f = args[0]
@@ -162,7 +165,7 @@ if __name__=="__main__":
     if opts.demo:
         run_demo()
     elif opts.f:
-        plot_hist(opts.f, opts.h, opts.b, opts.p, opts.colour, opts.t, opts.x)
+        plot_hist(opts.f, opts.h, opts.b, opts.p, opts.colour, opts.t, opts.x, opts.nosummary)
     else:
         print "nothing to plot!"
 
